@@ -53,14 +53,14 @@
 inline int f2int2 (float f)
 {
 	f += FLOATTOINTCONST2;
-	return ((*((int *)&f)) & 0x007fffff) - 0x00400000;
+	return ((*((int *)(void *)&f)) & 0x007fffff) - 0x00400000;
 }
 
 #define FLOATTOINTCONST (((1.5*65536*256)))
 inline int f2int (float f)
 {
 	f += FLOATTOINTCONST;
-	return ((*((int *)&f)) & 0x007fffff) - 0x00400000;
+	return ((*((int *)(void *)&f)) & 0x007fffff) - 0x00400000;
 }
 
 #define Float2Int(f) (f2int(f))
