@@ -25,9 +25,9 @@ void SVector3D::Print (char *s)
 // Randomly generates a new vector.
 void SVector3D::Rand ()
 {
-	x = 1.f - myRandf (2.f);
-	y = 1.f - myRandf (2.f);
-	z = 1.f - myRandf (2.f);
+	x = 1.f - rsRandf (2.f);
+	y = 1.f - rsRandf (2.f);
+	z = 1.f - rsRandf (2.f);
 }
 
 //-------------------------------------------
