@@ -18,13 +18,14 @@
 
 // SpirographX screen saver
 
+#include "driver.h"
+
 #include <math.h>
 #include <stdio.h>
 #include <stdlib.h>
 #include <GL/gl.h>
 #include <GL/glu.h>
 
-#include "driver.h"
 #include "rsDefines.h"
 #include "rsRand.h"
 
@@ -44,8 +45,7 @@ float lineAlpha;
 int animated;
 int timeInterval;
 
-float pointx[360 * MAXSUBLOOPS * MAXDETAIL];
-float pointy[360 * MAXSUBLOOPS * MAXDETAIL];
+float points[2 * 360 * MAXSUBLOOPS * MAXDETAIL];
 
 int colorBits, depthBits;
 int runningFullScreen;
@@ -79,32 +79,40 @@ void changeSettings ()
 void getAll ()
 {
 	int m, n;
-	float poweranswer, pointpoweroverdetail, moverd;
 
-	for (m = 0; m < 2 * PI * graphTo * DETAIL; m++) {
-		pointx[m] = 0;
-		pointy[m] = 0;
-		moverd = (float)m / DETAIL;
+	float poweranswer[SUBLOOPS];
+	poweranswer[0] = 1;
+	for (n = 1; n < SUBLOOPS; n++) {
+		poweranswer[n] = poweranswer[n - 1] * equationBase;
+	}
+
+	const int numberOfPoints = 2 * PI * graphTo * DETAIL;
+
+	memset(points, 0, numberOfPoints * 2 * sizeof(float));
+
+	for (m = 0; m < numberOfPoints; m++) {
+		const float moverd = (float)m / DETAIL;
 		for (n = 0; n < SUBLOOPS; n++) {
-			poweranswer = (float)pow (equationBase, n);
-			pointpoweroverdetail = (float)moverd *poweranswer;
+			const float pointpoweroverdetail = moverd * poweranswer[n];
+#ifdef _GNU_SOURCE
+			float sinppod, cosppod;
+			sincosf(pointpoweroverdetail, &sinppod, &cosppod);
+#else
+			const float sinppod = sin(pointpoweroverdetail);
+			const float cosppod = cos(pointpoweroverdetail);
+#endif
 
-			pointy[m] += sin (pointpoweroverdetail) / poweranswer;
-			pointx[m] += cos (pointpoweroverdetail) / poweranswer;
+			points[2 * m + 0] += cosppod / poweranswer[n];
+			points[2 * m + 1] += sinppod / poweranswer[n];
 		}
 	}
 }
 
 void drawAll ()
 {
-	int n;
+	const int numberOfPoints = 2 * PI * graphTo * DETAIL;
 
-	glBegin (GL_LINES);
-	for (n = 1; n < 2 * PI * graphTo * DETAIL; n++) {
-		glVertex3f (pointx[n - 1], pointy[n - 1], -3);
-		glVertex3f (pointx[n], pointy[n], -3);
-	}
-	glEnd ();
+	glDrawArrays(GL_LINE_STRIP, 0, numberOfPoints);
 }
 
 void hack_reshape (xstuff_t * XStuff)
@@ -121,6 +129,9 @@ void hack_init (xstuff_t * XStuff)	// Called right after the window is created,
 {
 	blurWidth = 5;
 
+	glVertexPointer(2, GL_FLOAT, 0, points);
+	glEnableClientState(GL_VERTEX_ARRAY);
+
 	glClearColor (0.0f, 0.0f, 0.0f, 0.5f);
 	glClearDepth (1.0f);
 	glEnable (GL_BLEND);
@@ -148,6 +159,8 @@ void hack_draw (xstuff_t * XStuff, double currentTime, float frameTime)
 	glLoadIdentity ();
 	getAll ();
 
+	glTranslatef(0.0, 0.0, -3.0f);
+
 	glLineWidth (blurWidth * sqrt((GLfloat) (XStuff->windowWidth * XStuff->windowHeight) / (500 * 400)));
 	glColor4f (blurColor[0], blurColor[1], blurColor[2], 0.2);
 	drawAll ();
