@@ -181,7 +181,7 @@ void bug::initFollower ()
 void bug::update (bug * bugs)
 {
 	int i;
-	float scale[4];
+	float scale[4] = { 0.0 };
 
 	if (!type) {		// leader
 		nextChange -= elapsedTime;
