@@ -44,11 +44,16 @@ class flux;
 class particle;
 
 // Global variables
+unsigned int tex;
 flux *fluxes;
 float lumdiff;
 int whichparticle;
 float cosCameraAngle, sinCameraAngle;
 unsigned char lightTexture[LIGHTSIZE][LIGHTSIZE];
+float aspectRatio;
+float orbitiness = 0.0f;
+float prevOrbitiness = 0.0f;
+
 
 // Parameters edited in the dialog box
 int dFluxes;
@@ -64,7 +69,6 @@ int dWind;
 int dInstability;
 int dBlur;
 int dSmart;
-int dPriority;
 
 // This class is poorly named.  It's actually a whole trail of particles.
 class particle {
@@ -153,6 +157,19 @@ float
 	vertices[counter][2] = vertices[oldc][2] + c[6] * offset[2] - cz + c[0] * vertices[oldc][0]
 		+ c[3] * vertices[oldc][1];
 
+	// calculate "orbitiness" of particles
+	const float xdiff(vertices[counter][0] - vertices[oldc][0]);
+	const float ydiff(vertices[counter][1] - vertices[oldc][1]);
+	const float zdiff(vertices[counter][2] - vertices[oldc][2]);
+	const float distsq(vertices[counter][0] * vertices[counter][0]
+		+ vertices[counter][1] * vertices[counter][1]
+		+ vertices[counter][2] * vertices[counter][2]);
+	const float oldDistsq(vertices[oldc][0] * vertices[oldc][0]
+		+ vertices[oldc][1] * vertices[oldc][1]
+		+ vertices[oldc][2] * vertices[oldc][2]);
+	orbitiness += (xdiff * xdiff + ydiff * ydiff + zdiff * zdiff)
+		/ (2.0f - fabs(distsq - oldDistsq));
+
 	// Pick a hue
 	vertices[counter][3] = cx * cx + cy * cy + cz * cz;
 	if (vertices[counter][3] > 1.0f)
@@ -174,15 +191,15 @@ float
 
 	// Bring particles back if they escape
 	if (!counter) {
-		if ((vertices[0][0] > 1000000000.0f)
-		    || (vertices[0][0] < -1000000000.0f)
-		    || (vertices[0][1] > 1000000000.0f)
-		    || (vertices[0][1] < -1000000000.0f)
-		    || (vertices[2][2] > 1000000000.0f)
-		    || (vertices[0][2] < -1000000000.0f)) {
-			vertices[0][0] = myRandf (2.0f) - 1.0f;
-			vertices[0][1] = myRandf (2.0f) - 1.0f;
-			vertices[0][2] = myRandf (2.0f) - 1.0f;
+		if ((vertices[0][0] > 10000.0f)
+		    || (vertices[0][0] < -10000.0f)
+		    || (vertices[0][1] > 10000.0f)
+		    || (vertices[0][1] < -10000.0f)
+		    || (vertices[2][2] > 10000.0f)
+		    || (vertices[0][2] < -10000.0f)) {
+			vertices[0][0] = rsRandf (2.0f) - 1.0f;
+			vertices[0][1] = rsRandf (2.0f) - 1.0f;
+			vertices[0][2] = rsRandf (2.0f) - 1.0f;
 		}
 	}
 	// Draw every vertex in particle trail
@@ -304,8 +321,8 @@ flux::flux ()
 	particles = new particle[dParticles];
 	randomize = 1;
 	for (i = 0; i < NUMCONSTS; i++) {
-		c[i] = myRandf (2.0f) - 1.0f;
-		cv[i] = myRandf (0.000005f * float (dInstability) * float (dInstability))
+		c[i] = rsRandf (2.0f) - 1.0f;
+		cv[i] = rsRandf (0.000005f * float (dInstability) * float (dInstability))
 		+ 0.000001f * float (dInstability) * float (dInstability);
 	}
 
@@ -328,11 +345,11 @@ void
 		randomize--;
 		if (randomize <= 0) {
 			for (i = 0; i < NUMCONSTS; i++)
-				c[i] = myRandf (2.0f) - 1.0f;
+				c[i] = rsRandf (2.0f) - 1.0f;
 			int temp = 101 - dRandomize;
 
 			temp = temp * temp;
-			randomize = temp + myRandi (temp);
+			randomize = temp + rsRandi (temp);
 		}
 	}
 	// update constants
@@ -348,6 +365,9 @@ void
 		}
 	}
 
+	prevOrbitiness = orbitiness;
+	orbitiness = 0.0f;
+
 	// update all particles in this flux field
 	float dist;
 
@@ -373,9 +393,14 @@ void
 		}
 		oldDistance = dist;
 	}
+
+	if (orbitiness < prevOrbitiness) {
+		i = rsRandi(NUMCONSTS - 1);
+		cv[i] = -cv[i];
+	}
 }
 
-void hack_draw (xstuff_t * XStuff)
+void hack_draw (xstuff_t * XStuff, double currentTime, float frameTime)
 {
 
 	int i;
@@ -384,17 +409,26 @@ void hack_draw (xstuff_t * XStuff)
 	// clear the screen
 	glLoadIdentity ();
 	if (dBlur) {		// partially
-		glBlendFunc (GL_SRC_ALPHA, GL_ONE_MINUS_SRC_ALPHA);
-		glEnable (GL_BLEND);
-		glDisable (GL_DEPTH_TEST);
-		glColor4f (0.0f, 0.0f, 0.0f, 0.5f - (float (sqrt (sqrt (double (dBlur)))) * 0.15495f));
-
-		glBegin (GL_TRIANGLE_STRIP);
-		glVertex3f (-16.0f, -12.0f, 0.0f);
-		glVertex3f (16.0f, -12.0f, 0.0f);
-		glVertex3f (-16.0f, 12.0f, 0.0f);
-		glVertex3f (16.0f, 12.0f, 0.0f);
-		glEnd ();
+		glMatrixMode(GL_PROJECTION);
+		glPushMatrix();
+			glLoadIdentity();
+			glOrtho(0.0, 1.0, 0.0, 1.0, 1.0, -1.0);
+			glMatrixMode(GL_MODELVIEW);
+			glPushMatrix();
+				glLoadIdentity();
+				glBlendFunc(GL_SRC_ALPHA, GL_ONE_MINUS_SRC_ALPHA);
+				glEnable(GL_BLEND);
+				glDisable(GL_DEPTH_TEST);
+				glColor4f(0.0f, 0.0f, 0.0f, 0.5f - (float(sqrtf(sqrtf(float(dBlur)))) * 0.15495f));
+				glBegin(GL_TRIANGLE_STRIP);
+					glVertex3f(0.0f, 0.0f, 0.0f);
+					glVertex3f(1.0f, 0.0f, 0.0f);
+					glVertex3f(0.0f, 1.0f, 0.0f);
+					glVertex3f(1.0f, 1.0f, 0.0f);
+				glEnd();
+			glPopMatrix();
+		glMatrixMode(GL_PROJECTION);
+		glPopMatrix();
 	} else			// completely
 		glClear (GL_COLOR_BUFFER_BIT);
 
@@ -409,7 +443,7 @@ void hack_draw (xstuff_t * XStuff)
 		sinCameraAngle = sin (cameraAngle * DEG2RAD);
 	}
 
-	// set up blend modes for rendering particles
+	// set up state for rendering particles
 	switch (dGeometry) {
 	case 0:		// Blending for points
 		glBlendFunc (GL_SRC_ALPHA, GL_ONE);
@@ -426,9 +460,12 @@ void hack_draw (xstuff_t * XStuff)
 	case 2:		// Blending for lights
 		glBlendFunc (GL_ONE, GL_ONE);
 		glEnable (GL_BLEND);
+		glBindTexture(GL_TEXTURE_2D, tex);
+		glEnable(GL_TEXTURE_2D);
 	}
 
 	// Update particles
+	glMatrixMode(GL_MODELVIEW);
 	for (i = 0; i < dFluxes; i++)
 		fluxes[i].update ();
 
@@ -444,12 +481,15 @@ void hack_reshape (xstuff_t * XStuff)
 
 	glMatrixMode (GL_PROJECTION);
 	glLoadIdentity ();
-	gluPerspective (100.0, float (XStuff->windowWidth) / float (XStuff->windowHeight), 0.01, 200);
 
-	glTranslatef (0.0, 0.0, -2.5);
+	aspectRatio = float (XStuff->windowWidth) / float (XStuff->windowHeight);
+	gluPerspective (100.0, aspectRatio, 0.01, 200);
+
 	glMatrixMode (GL_MODELVIEW);
 	glLoadIdentity ();
 
+	glTranslatef (0.0, 0.0, -2.5);
+
 	if (dGeometry == 0) {
 		glEnable (GL_POINT_SMOOTH);
 		// glHint(GL_POINT_SMOOTH_HINT, GL_NICEST);
@@ -515,8 +555,8 @@ void hack_reshape (xstuff_t * XStuff)
 				lightTexture[i][j] = char (255.0f * temp * temp);
 			}
 		}
-		glEnable (GL_TEXTURE_2D);
-		glBindTexture (GL_TEXTURE_2D, 1);
+		glGenTextures(1, &tex);
+		glBindTexture(GL_TEXTURE_2D, tex);
 		glTexEnvf (GL_TEXTURE_ENV, GL_TEXTURE_ENV_MODE, GL_MODULATE);
 		glTexParameteri (GL_TEXTURE_2D, GL_TEXTURE_MAG_FILTER, GL_LINEAR);
 		glTexParameteri (GL_TEXTURE_2D, GL_TEXTURE_MIN_FILTER, GL_LINEAR);
@@ -525,7 +565,6 @@ void hack_reshape (xstuff_t * XStuff)
 		temp = float (dSize) * 0.005f;
 
 		glNewList (1, GL_COMPILE);
-		glBindTexture (GL_TEXTURE_2D, 1);
 		glBegin (GL_TRIANGLES);
 		glTexCoord2f (0.0f, 0.0f);
 		glVertex3f (-temp, -temp, 0.0f);
@@ -780,6 +819,6 @@ void hack_handle_opts (int argc, char **argv)
 	}
 
 	if (!change_flag) {
-		setDefaults (myRandi (6) + 1);
+		setDefaults (rsRandi (6) + 1);
 	}
 }
