@@ -408,13 +408,10 @@ void hack_reshape (xstuff_t * XStuff)
 #ifdef HAVE_GLEW
 bool initExtensions() 
 {
-	GLenum err = glewInit();
-
-	if (GLEW_OK != err) {
+	if (!glewInitialized)
 		return false;
-	}
 
-	char *necessaryExtensions[4] = { "GL_ARB_multitexture", "GL_ARB_texture_cube_map", "GL_ARB_vertex_program", "GL_ARB_fragment_program" };
+	const char *necessaryExtensions[4] = { "GL_ARB_multitexture", "GL_ARB_texture_cube_map", "GL_ARB_vertex_program", "GL_ARB_fragment_program" };
 
 	for (int i = 0; i < 4; i++)
 		if (GL_TRUE != glewGetExtension(necessaryExtensions[i]))
