@@ -20,10 +20,8 @@
 
 #include <math.h>
 #include <stdio.h>
-#include <time.h>
 #include <GL/gl.h>
 #include <GL/glu.h>
-#include <sys/time.h>
 
 #include <list>
 
@@ -31,7 +29,7 @@
 #include "rgbhsl.h"
 #include "rsDefines.h"
 #include "rsRand.h"
-#include "rsVec.h"
+#include "rsMath/rsVec.h"
 #include "skyrocket_flare.h"
 #include "skyrocket_particle.h"
 #include "skyrocket_smoke.h"
@@ -182,7 +180,7 @@ void draw ()
 	static float cameraTime[3] = { 20.0f, 0.0f, 0.0f };
 
 	// super fast easter egg
-	if (!myRandi (2000))
+	if (!rsRandi (2000))
 		elapsedTime *= 5.0f;
 
 	// build viewing matrix
@@ -192,23 +190,23 @@ void draw ()
 	glGetDoublev (GL_PROJECTION_MATRIX, projMat);
 
 	if (kNewCamera) {	// Make new random camera view
-		cameraTime[0] = myRandf (25.0f) + 5.0f;
+		cameraTime[0] = rsRandf (25.0f) + 5.0f;
 		cameraTime[1] = 0.0f;
 		cameraTime[2] = 0.0f;
 		// choose new positions
-		lookFrom[1][0] = myRandf (6000.0f) - 3000.0f;	// new target position
-		lookFrom[1][1] = myRandf (1700.0f) + 5.0f;
-		lookFrom[1][2] = myRandf (6000.0f) - 3000.0f;
-		lookAt[1][0] = myRandf (1000.0f) - 500.0f;	// new target position
-		lookAt[1][1] = myRandf (1100.0f) + 200.0f;
-		lookAt[1][2] = myRandf (1000.0f) - 500.0f;
+		lookFrom[1][0] = rsRandf (6000.0f) - 3000.0f;	// new target position
+		lookFrom[1][1] = rsRandf (1700.0f) + 5.0f;
+		lookFrom[1][2] = rsRandf (6000.0f) - 3000.0f;
+		lookAt[1][0] = rsRandf (1000.0f) - 500.0f;	// new target position
+		lookAt[1][1] = rsRandf (1100.0f) + 200.0f;
+		lookAt[1][2] = rsRandf (1000.0f) - 500.0f;
 		// cut to a new view
-		lookFrom[2][0] = myRandf (6000.0f) - 3000.0f;	// new last position
-		lookFrom[2][1] = myRandf (1700.0f) + 5.0f;
-		lookFrom[2][2] = myRandf (6000.0f) - 3000.0f;
-		lookAt[2][0] = myRandf (1000.0f) - 500.0f;	// new last position
-		lookAt[2][1] = myRandf (1100.0f) + 200.0f;
-		lookAt[2][2] = myRandf (1000.0f) - 500.0f;
+		lookFrom[2][0] = rsRandf (6000.0f) - 3000.0f;	// new last position
+		lookFrom[2][1] = rsRandf (1700.0f) + 5.0f;
+		lookFrom[2][2] = rsRandf (6000.0f) - 3000.0f;
+		lookAt[2][0] = rsRandf (1000.0f) - 500.0f;	// new last position
+		lookAt[2][1] = rsRandf (1100.0f) + 200.0f;
+		lookAt[2][2] = rsRandf (1000.0f) - 500.0f;
 		kNewCamera = 0;
 	}
 
@@ -218,38 +216,38 @@ void draw ()
 			cameraTime[1] = 0.0f;
 			cameraTime[2] = 0.0f;
 			lookFrom[2] = lookFrom[0];
-			lookFrom[1][0] = myRandf (6000.0f) - 3000.0f;	// new target position
-			lookFrom[1][1] = myRandf (1700.0f) + 5.0f;
-			lookFrom[1][2] = myRandf (6000.0f) - 3000.0f;
+			lookFrom[1][0] = rsRandf (6000.0f) - 3000.0f;	// new target position
+			lookFrom[1][1] = rsRandf (1700.0f) + 5.0f;
+			lookFrom[1][2] = rsRandf (6000.0f) - 3000.0f;
 			lookAt[2] = lookAt[0];
-			lookAt[1][0] = myRandf (1000.0f) - 500.0f;	// new target position
-			lookAt[1][1] = myRandf (1100.0f) + 200.0f;
-			lookAt[1][2] = myRandf (1000.0f) - 500.0f;
+			lookAt[1][0] = rsRandf (1000.0f) - 500.0f;	// new target position
+			lookAt[1][1] = rsRandf (1100.0f) + 200.0f;
+			lookAt[1][2] = rsRandf (1000.0f) - 500.0f;
 		}
 
 		cameraTime[1] += elapsedTime;
 		cameraTime[2] = cameraTime[1] / cameraTime[0];
 		if (cameraTime[2] >= 1.0f) {	// reset camera sequence
 			// reset timer
-			cameraTime[0] = myRandf (25.0f) + 5.0f;
+			cameraTime[0] = rsRandf (25.0f) + 5.0f;
 			cameraTime[1] = 0.0f;
 			cameraTime[2] = 0.0f;
 			// choose new positions
 			lookFrom[2] = lookFrom[1];	// last = target
-			lookFrom[1][0] = myRandf (6000.0f) - 3000.0f;	// new target position
-			lookFrom[1][1] = myRandf (1700.0f) + 5.0f;
-			lookFrom[1][2] = myRandf (6000.0f) - 3000.0f;
+			lookFrom[1][0] = rsRandf (6000.0f) - 3000.0f;	// new target position
+			lookFrom[1][1] = rsRandf (1700.0f) + 5.0f;
+			lookFrom[1][2] = rsRandf (6000.0f) - 3000.0f;
 			lookAt[2] = lookAt[1];	// last = target
-			lookAt[1][0] = myRandf (1000.0f) - 500.0f;	// new target position
-			lookAt[1][1] = myRandf (1100.0f) + 200.0f;
-			lookAt[1][2] = myRandf (1000.0f) - 500.0f;
-			if (!myRandi (3)) {	// cut to a new view
-				lookFrom[2][0] = myRandf (6000.0f) - 3000.0f;	// new last position
-				lookFrom[2][1] = myRandf (1700.0f) + 5.0f;
-				lookFrom[2][2] = myRandf (6000.0f) - 3000.0f;
-				lookAt[2][0] = myRandf (1000.0f) - 500.0f;	// new last position
-				lookAt[2][1] = myRandf (1100.0f) + 200.0f;
-				lookAt[2][2] = myRandf (1000.0f) - 500.0f;
+			lookAt[1][0] = rsRandf (1000.0f) - 500.0f;	// new target position
+			lookAt[1][1] = rsRandf (1100.0f) + 200.0f;
+			lookAt[1][2] = rsRandf (1000.0f) - 500.0f;
+			if (!rsRandi (3)) {	// cut to a new view
+				lookFrom[2][0] = rsRandf (6000.0f) - 3000.0f;	// new last position
+				lookFrom[2][1] = rsRandf (1700.0f) + 5.0f;
+				lookFrom[2][2] = rsRandf (6000.0f) - 3000.0f;
+				lookAt[2][0] = rsRandf (1000.0f) - 500.0f;	// new last position
+				lookAt[2][1] = rsRandf (1100.0f) + 200.0f;
+				lookAt[2][2] = rsRandf (1000.0f) - 500.0f;
 			}
 		}
 
@@ -370,10 +368,10 @@ void draw ()
 
 		changeRocketTimeConst -= elapsedTime;
 		if (changeRocketTimeConst <= 0.0f) {
-			float temp = myRandf (4.0f);
+			float temp = rsRandf (4.0f);
 
 			rocketTimeConst = (temp * temp) + (10.0f / float (dMaxrockets));
-			changeRocketTimeConst = myRandf (30.0f) + 10.0f;
+			changeRocketTimeConst = rsRandf (30.0f) + 10.0f;
 		}
 
 		// add new rocket to list
@@ -382,37 +380,37 @@ void draw ()
 			if (numRockets < dMaxrockets) {
 				particle *rock = addParticle ();
 
-				if (myRandi (30) || (userDefinedExplosion >= 0)) {	// Usually launch a rocket
+				if (rsRandi (30) || (userDefinedExplosion >= 0)) {	// Usually launch a rocket
 					rock->initRocket ();
 					if (userDefinedExplosion >= 0)
 						rock->explosiontype = userDefinedExplosion;
 					else {
-						if (!myRandi (3000)) {	// big one!
-							if (myRandi (2))
+						if (!rsRandi (3000)) {	// big one!
+							if (rsRandi (2))
 								rock->explosiontype = 19;	// sucker and shockwave
 							else
 								rock->explosiontype = 20;	// stretcher and bigmama
 						} else {
 							// Distribution of regular explosions
-							if (myRandi (2)) {	// 0 - 2 (all types of spheres)
-								if (!myRandi (10))
+							if (rsRandi (2)) {	// 0 - 2 (all types of spheres)
+								if (!rsRandi (10))
 									rock->explosiontype = 2;
 								else
-									rock->explosiontype = myRandi (2);
+									rock->explosiontype = rsRandi (2);
 							} else {
-								if (!myRandi (3))	//  ring, double sphere, sphere and ring
-									rock->explosiontype = myRandi (3) + 3;
+								if (!rsRandi (3))	//  ring, double sphere, sphere and ring
+									rock->explosiontype = rsRandi (3) + 3;
 								else {
-									if (myRandi (2)) {	// 6, 7, 8, 9, 10, 11
-										if (myRandi (2))
-											rock->explosiontype = myRandi (2) + 6;
+									if (rsRandi (2)) {	// 6, 7, 8, 9, 10, 11
+										if (rsRandi (2))
+											rock->explosiontype = rsRandi (2) + 6;
 										else
-											rock->explosiontype = myRandi (4) + 8;
+											rock->explosiontype = rsRandi (4) + 8;
 									} else {
-										if (myRandi (2))	// 12, 13, 14
-											rock->explosiontype = myRandi (3) + 12;
+										if (rsRandi (2))	// 12, 13, 14
+											rock->explosiontype = rsRandi (3) + 12;
 										else	// 15 - 18
-											rock->explosiontype = myRandi (4) + 15;
+											rock->explosiontype = rsRandi (4) + 15;
 									}
 								}
 							}
@@ -421,7 +419,7 @@ void draw ()
 					numRockets++;
 				} else {	// sometimes make fountains and spinners instead of rockets
 					rock->initFountain ();
-					i = myRandi (2);
+					i = rsRandi (2);
 					for (j = 0; j < i; j++) {
 						rock = addParticle ();
 						rock->initFountain ();
@@ -430,7 +428,7 @@ void draw ()
 			}
 
 			if (dMaxrockets)
-				rocketTimer = myRandf (rocketTimeConst);
+				rocketTimer = rsRandf (rocketTimeConst);
 			else
 				rocketTimer = 60.0f;	// arbitrary number since no rockets ever fire
 
@@ -539,32 +537,19 @@ void draw ()
 	glFlush ();
 }
 
-void hack_draw (xstuff_t * XStuff)
+void hack_draw (xstuff_t * XStuff, double currentTime, float frameTime)
 {
 	static float times[5] = { 0.03f, 0.03f, 0.03f, 0.03f, 0.03f };
 	static int timeindex = 0;
-	static int lastTime = -1;
-	int thisTime;
-	struct timeval now;
 #ifdef BENCHMARK
 	static int a = 1;
 #endif
 
-	/*
-	 * update time 
-	 */
-	gettimeofday (&now, NULL);
-	thisTime = (now.tv_sec & 65535) * 1000 + now.tv_usec / 1000;
-
-	if (lastTime == -1)
-		lastTime = thisTime;
-
-	if (thisTime >= lastTime) {
-		times[timeindex] = float (thisTime - lastTime) * 0.001f;
+	if (frameTime > 0) {
+		times[timeindex] = frameTime;
 	} else {		// else use elapsedTime from last frame
 		times[timeindex] = elapsedTime;
 	}
-	lastTime = thisTime;
 
 #ifdef BENCHMARK
 	times[timeindex] = 0.03f;
@@ -617,8 +602,8 @@ void hack_init (xstuff_t * XStuff)
 	initWorld ();
 	initShockwave ();
 
-	lookFrom[1] = rsVec (myRandf (3000.0f) - 1500.0f, 400.0f, myRandf (3000.0f) - 1500.0f);
-	lookFrom[2] = rsVec (myRandf (1000.0f) + 5000.0f, 5.0f, myRandf (4000.0f) - 2000.0f);
+	lookFrom[1] = rsVec (rsRandf (3000.0f) - 1500.0f, 400.0f, rsRandf (3000.0f) - 1500.0f);
+	lookFrom[2] = rsVec (rsRandf (1000.0f) + 5000.0f, 5.0f, rsRandf (4000.0f) - 2000.0f);
 
 #ifdef HAVE_OPENAL
 	if (dSound)
