@@ -1,10 +1,10 @@
 #ifndef DRIVER_H
 #define DRIVER_H
 
-#include <X11/Intrinsic.h>
-
 #include "config.h"
 
+#include <X11/Intrinsic.h>
+
 #define ATTR_ALIGN(x) __attribute__ ((aligned(x)))
 
 #ifdef HAVE_GETOPT_H
@@ -38,13 +38,13 @@ typedef struct xstuff {
 	void *hackstuff;
 } xstuff_t;
 
-#define DRIVER_OPTIONS_LONG {"root", 0, 0, 'r'}, {"maxfps", 1, 0, 'x'}, {"nice", 0, 0, 'n'},
-#define DRIVER_OPTIONS_SHORT "rx:n"
-#define DRIVER_OPTIONS_HELP "\t--root/-r\n" "\t--maxfps/-x <arg>\n" "\t--nice/-n\n"
-#define DRIVER_OPTIONS_CASES case 'r': case 'x': case 'n': handle_global_opts(c); break;
+#define DRIVER_OPTIONS_LONG {"root", 0, 0, 'r'}, {"maxfps", 1, 0, 'x'}, {"vsync", 1, 0, 'y'},
+#define DRIVER_OPTIONS_SHORT "rx:y:"
+#define DRIVER_OPTIONS_HELP "\t--root/-r\n" "\t--maxfps/-x <arg>\n" "\t--vsync/-y <arg>\n"
+#define DRIVER_OPTIONS_CASES case 'r': case 'x': case 'y': handle_global_opts(c); break;
 
 void handle_global_opts (int c);
-int strtol_minmaxdef(char *optarg, int base, int min, int max, int type, int def, char *errmsg);
+int strtol_minmaxdef(const char *optarg, const int base, const int min, const int max, const int type, const int def, const char *errmsg);
 
 void hack_handle_opts (int argc, char **argv);
 void hack_init (xstuff_t *);
@@ -52,4 +52,6 @@ void hack_reshape (xstuff_t *);
 void hack_draw (xstuff_t *, double, float);
 void hack_cleanup (xstuff_t *);
 
+extern int glewInitialized;
+
 #endif
